/*
 * This file is a part of EZC -- Easy templating in C++
 * and is distributed under the (new) BSD licence.
 * Author: Tomasz Sowa <t.sowa@ttmath.org>
 */

/* 
 * Copyright (c) 2007-2014, Tomasz Sowa
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *    
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *    
 *  * Neither the name Tomasz Sowa nor the names of contributors to this
 *    project may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "pattern.h"
#include "utf8/utf8.h"


namespace Ezc
{


Pattern::Pattern()
{
	// !!!!! IMPROVE ME as default there can be empty strings
	commentary_start = L"<!-- ";
	commentary_stop  = L" -->";
	Clear();
}



void Pattern::Clear()
{
	item_root.Clear();
}






void Pattern::SetCommentary(const char * com_start, const char * com_stop)
{
	PT::UTF8ToWide(com_start, commentary_start);
	PT::UTF8ToWide(com_stop,  commentary_stop);
}



void Pattern::SetCommentary(const std::string & com_start, const std::string & com_stop)
{
	PT::UTF8ToWide(com_start, commentary_start);
	PT::UTF8ToWide(com_stop,  commentary_stop);
}



void Pattern::SetCommentary(const wchar_t * com_start, const wchar_t * com_stop)
{
	commentary_start = com_start;
	commentary_stop  = com_stop;
}



void Pattern::SetCommentary(const std::wstring & com_start, const std::wstring & com_stop)
{
	commentary_start = com_start;
	commentary_stop  = com_stop;
}





void Pattern::CreateMsg(std::wstring & out, const wchar_t * type, const wchar_t * arg)
{
	out = commentary_start;
	out += L"Ezc: ";
	out += type;

	if( arg )
	{
		out += ' ';
		out += arg;
	}

	out += commentary_stop;
}







} // namespace Ezc



